@@ -1,8 +1,5 @@
-from autodiff_107.diff import Node
+from autodiff_107.diff.Node import Node
 from autodiff_107.optim import gradient_descent
-# from Node import Var
-# from Node import variable
-# from nodemath import numpy
 from autodiff_107.diff import numpy as np
 import pytest
 
